==> notolog-0.9.1b3.tar.gz: notolog-0.9.1b3/notolog/lexemes/fr/toolbar.py <==
# French lexemes toolbar.py
lexemes = {
    "actions_label_new_document": "Nouveau document",
    "actions_accessible_name_new_document": "Nouveau document",
    "actions_label_open": "Ouvrir",
    "actions_accessible_name_open": "Ouvrir le document",
    "actions_label_save": "Enregistrer",
    "actions_accessible_name_save": "Enregistrer le document",
    "actions_label_save_as": "Enregistrer sous",
    "actions_accessible_name_save_as": "Enregistrer une copie du document",
    "actions_label_sync": "Synchroniser",
    "actions_accessible_name_sync": "Synchroniser le document avec un stockage externe",
    "actions_label_edit": "Éditer",
    "actions_accessible_name_edit": "Éditer le fichier",
    "actions_label_source": "Source",
    "actions_accessible_name_source": "Code source",
    "actions_label_encrypt": "Chiffrer",
    "actions_accessible_name_encrypt": "Chiffrer le fichier",
    "actions_label_decrypt": "Déchiffrer",
    "actions_accessible_name_decrypt": "Déchiffrer le fichier",
    "actions_label_bold": "Gras",
    "actions_accessible_name_bold": "Format de texte en gras",
    "actions_label_italic": "Italique",
    "actions_accessible_name_italic": "Format de texte en italique",
    "actions_label_underline": "Souligner",
    "actions_accessible_name_underline": "Format de texte souligné",
    "actions_label_strikethrough": "Barré",
    "actions_accessible_name_strikethrough": "Format de texte barré",
    "actions_label_blockquote": "Citation",
    "actions_accessible_name_blockquote": "Format de texte en citation",
    "actions_label_color_picker": "Sélecteur de couleur",
    "actions_accessible_name_color_picker": "Choisir une couleur de texte",
    "actions_label_ai_assistant": "Assistant IA",
    "actions_accessible_name_ai_assistant": "Exécuter l'assistant IA",
    "actions_label_about": "À propos",
    "actions_accessible_name_about": "À propos de l'App",
    "actions_label_exit": "Quitter",
    "actions_accessible_name_exit": "Quitter l'App",
    "actions_label_settings": "Paramètres",
    "actions_accessible_name_settings": "Paramètres de l'application",

    "search_input_label": "Rechercher",
    "search_input_placeholder_text": "texte dans le document",
    "search_input_accessible_description": "Champ de recherche",
    "search_buttons_label_clear": "Effacer la recherche",
    "search_buttons_accessible_name_clear": "Effacer le champ de recherche",
    "search_buttons_label_prev": "Recherche précédente",
    "search_buttons_accessible_name_prev": "Résultat de recherche précédent",
    "search_buttons_label_next": "Recherche suivante",
    "search_buttons_accessible_name_next": "Résultat de recherche suivant",
    "search_case_sensitive": "Sensible à la casse",
    "search_match_case_tooltip": "Recherche sensible à la casse",
}

==> notolog-1.1.5.tar.gz: notolog-1.1.5/notolog/lexemes/fr/toolbar.py <==
# French lexemes toolbar.py
lexemes = {
    "actions_label_new_document": "Nouveau document",
    "actions_accessible_name_new_document": "Nouveau document",
    "actions_label_open": "Ouvrir",
    "actions_accessible_name_open": "Ouvrir le document",
    "actions_label_save": "Enregistrer",
    "actions_accessible_name_save": "Enregistrer le document",
    "actions_label_save_as": "Enregistrer sous",
    "actions_accessible_name_save_as": "Enregistrer une copie du document",
    "actions_label_sync": "Synchroniser",
    "actions_accessible_name_sync": "Synchroniser le document avec un stockage externe",
    "actions_label_edit": "Éditer",
    "actions_accessible_name_edit": "Éditer le fichier",
    "actions_label_source": "Source",
    "actions_accessible_name_source": "Code source",
    "actions_label_encrypt": "Chiffrer",
    "actions_accessible_name_encrypt": "Chiffrer le fichier",
    "actions_label_decrypt": "Déchiffrer",
    "actions_accessible_name_decrypt": "Déchiffrer le fichier",
    "actions_label_bold": "Gras",
    "actions_accessible_name_bold": "Format de texte en gras",
    "actions_label_italic": "Italique",
    "actions_accessible_name_italic": "Format de texte en italique",
    "actions_label_underline": "Souligner",
    "actions_accessible_name_underline": "Format de texte souligné",
    "actions_label_strikethrough": "Barré",
    "actions_accessible_name_strikethrough": "Format de texte barré",
    "actions_label_blockquote": "Citation",
    "actions_accessible_name_blockquote": "Format de texte en citation",
    "actions_label_color_picker": "Sélecteur de couleur",
    "actions_accessible_name_color_picker": "Choisir une couleur de texte",
    "actions_label_ai_assistant": "Assistant IA",
    "actions_accessible_name_ai_assistant": "Exécuter l'assistant IA",
    "actions_label_about": "À propos",
    "actions_accessible_name_about": "À propos de l'App",
    "actions_label_exit": "Quitter",
    "actions_accessible_name_exit": "Quitter l'App",
    "actions_label_settings": "Paramètres",
    "actions_accessible_name_settings": "Paramètres de l'application",

    "search_input_label": "Rechercher",
    "search_input_placeholder_text": "Rechercher du texte dans le document",
    "search_input_accessible_description": "Champ de recherche",
    "search_buttons_label_clear": "Effacer la recherche",
    "search_buttons_accessible_name_clear": "Effacer le champ de recherche",
    "search_buttons_label_prev": "Recherche précédente",
    "search_buttons_accessible_name_prev": "Résultat de recherche précédent",
    "search_buttons_label_next": "Recherche suivante",
    "search_buttons_accessible_name_next": "Résultat de recherche suivant",
    "search_case_sensitive_accessible_name": "Sensible à la casse",
    "search_case_sensitive_tooltip": "Recherche sensible à la casse",
}
